==> tetzle_2.1.6.orig.tar.gz: tetzle-2.1.6/translations/tetzle_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Ouvrir une image</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Apparence</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Coins biseautés</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Dissiper les zones d&apos;ombre</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Couleurs</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Arrière-plan :</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Ombre :</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Surbrillance :</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Image manquante.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Veuillez patienter</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Chargement de l&apos;image…</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Génération du puzzle…</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Création des pièces…</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Chargement du puzzle…</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Format de donnée inconnu</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Élément inconnu &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Erreur d&apos;analyse du fichier XML.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Chargement des pièces…</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Pioche des pièces…</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Disposition des pièces…</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Succès</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Choisir une partie</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Parties en cours</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Nouvelle partie</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Propriétés de l&apos;image</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Mot-cles :</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Sélectionner la langue de l&apos;application :</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Langue du système&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Remarque</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Veuillez relancer l&apos;application pour que la modification prenne effet. </translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Ajouter une image</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Supprimer l&apos;image</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Propriétés de l&apos;image</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 pièces</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Copie des images…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation>Supprimer l&apos;image sélectionnée ?</translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Supprimer l&apos;image sélectionnée ?

Les parties utilisant cette image seront également supprimées.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sans titre</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Sans titre</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 pièces %2 %3% terminées</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Supprimer la partie</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Supprimer la partie sélectionnée ?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Vue d&apos;ensemble</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Ajouter un mot-clef</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Supprimer le mot-clef</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Mot-clef retiré</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Toutes les images</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Sans titre %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Supprimer le mot-clef sélectionné ?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Désolé</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Un mot-clef identique existe déjà.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Jeu</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Piocher des pièces</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Choisir…</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Afficher</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Zoom &amp;avant</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Zoom &amp;arrière</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>&amp;Mise au point optimale</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Afficher la &amp;vue d&apos;ensemble</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>&amp;Plein écran</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Paramètres</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Apparence…</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Langue…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Commandes</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>À &amp;propos de…</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>À propos de &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Contrôles</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Ramasser des pièces :&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Clic gauche ou Barre d&apos;espace</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Relâcher des pièces :&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Sélectionner des pièces :&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Faire glisser à gauche</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Rotation des pièces :&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Clic droit, Contrôle + Clic gauche, ou R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Faire glisser le puzzle :&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Clic du milieu, Maj + Clic gauche, ou flèches</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Zoomer sur le puzzle :&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Molette ou + / -</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Curseur de la souris :&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Déplacez la souris ou utilisez W,A,D,S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>À propos de Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Un puzzle Jigsaw à base de tétraminos</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Distribué sous licence GNU &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>??%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>version</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> tetzle_3.0.1.orig.tar.gz: tetzle-3.0.1/translations/tetzle_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Ouvrir une image</translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Apparence</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Coins biseautés</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Dissiper les zones d&apos;ombre</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Couleurs</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Arrière-plan :</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Ombre :</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Surbrillance :</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Image manquante.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Veuillez patienter</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Chargement de l&apos;image…</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Génération du puzzle…</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Création des pièces…</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Chargement du puzzle…</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Format de donnée inconnu</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Élément inconnu &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Erreur d&apos;analyse du fichier XML.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Chargement des pièces…</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Pioche des pièces…</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Disposition des pièces…</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Succès</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Choisir une partie</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Parties en cours</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Nouvelle partie</translation>
    </message>
    <message>
        <source>Play Game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Propriétés de l&apos;image</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Mot-cles :</translation>
    </message>
    <message>
        <source>New tag name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Sélectionner la langue de l&apos;application :</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Langue du système&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Remarque</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Veuillez relancer l&apos;application pour que la modification prenne effet. </translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Ajouter une image</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Supprimer l&apos;image</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Propriétés de l&apos;image</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 pièces</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Copie des images…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sans titre</translation>
    </message>
    <message numerus="yes">
        <source>Remove %n selected image(s)?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Saved games using these image(s) will be deleted.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Sans titre</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 pièces %2 %3% terminées</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Supprimer la partie</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Supprimer la partie sélectionnée ?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Vue d&apos;ensemble</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Ajouter un mot-clef</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Supprimer le mot-clef</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Mot-clef retiré</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Toutes les images</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Sans titre %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Supprimer le mot-clef sélectionné ?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Désolé</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Un mot-clef identique existe déjà.</translation>
    </message>
    <message>
        <source>Manage Tags...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Jeu</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Piocher des pièces</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Choisir…</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Afficher</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Zoom &amp;avant</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Zoom &amp;arrière</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>&amp;Mise au point optimale</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Afficher la &amp;vue d&apos;ensemble</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>&amp;Plein écran</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Paramètres</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Apparence…</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Langue…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Commandes</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>À &amp;propos de…</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>À propos de &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Contrôles</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Ramasser des pièces :&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Clic gauche ou Barre d&apos;espace</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Relâcher des pièces :&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Sélectionner des pièces :&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Faire glisser à gauche</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Rotation des pièces :&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Clic droit, Contrôle + Clic gauche, ou R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Faire glisser le puzzle :&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Clic du milieu, Maj + Clic gauche, ou flèches</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Zoomer sur le puzzle :&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Molette ou + / -</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Curseur de la souris :&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Déplacez la souris ou utilisez W,A,D,S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>À propos de Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Un puzzle Jigsaw à base de tétraminos</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Distribué sous licence GNU &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>%p% complete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>Zoom: %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
